@@ -20,6 +20,6 @@ addr_t addr;
 	struct semaphore sem;
 
 	memread(addr, sizeof(struct semaphore), &sem, "semaphore");
-	mprintf(FPTR " %4x %5x\n", addr, sem.count.counter, sem.waking);
+	mprintf(FPTR " %4d %5d\n", addr, sem.count.counter, sem.waking);
 	return 0;
 }
