@@ -22,6 +22,8 @@ extern const commandtable_t
 	command_request_queue,
 	command_rtable,
 	command_slab,
+	command_sock,
+	command_socket,
 	command_tq_struct,
 	command_timer_vec,
 	command_usb_bus,
@@ -59,6 +61,8 @@ const commandtable_t *commandtable_vers[] = {
 	&command_request_queue,
 	&command_rtable,
 	&command_slab,
+	&command_sock,
+	&command_socket,
 	&command_tq_struct,
 	&command_timer_vec,
 #ifdef CONFIG_USB
