@@ -187,7 +187,7 @@ print_inode(addr, full)
 		print_kdev_t(inode.i_rdev);
 		mprintf("  blksize:%ld  blocks:%ld  version:%ld\n", inode.i_blksize, inode.i_blocks, inode.i_version);
 		mprintf("\tatime:%08lx  mtime:%08lx  ctime:%08lx\n", inode.i_atime, inode.i_mtime, inode.i_ctime);
-		mprintf("\tSEM (count:%x  sleepers:%x)\n", ATOMIC_READ(inode.i_sem.count), inode.i_sem.sleepers);
+		mprintf("\tSEM (count:%d  sleepers:%d)\n", ATOMIC_READ(inode.i_sem.count), inode.i_sem.sleepers);
 		mprintf("\top:" FPTR "  fop:" FPTR "  sb:" FPTR "  flock:" FPTR "\n", inode.i_op, inode.i_fop, inode.i_sb, inode.i_flock);
 		mprintf("\tbdev:%lx  gen:%u  generic_ip:" FPTR "\n", inode.i_bdev, inode.i_generation, inode.u.generic_ip);
 		mprintf("\tlist: " FPTR " " FPTR "\n",
@@ -203,7 +203,7 @@ print_inode(addr, full)
 void
 prhead_superblock()
 {
-	mprintf(SPTR"   DEV   BSIZE        TYPE "SPTR"    MAGIC "SPTR" "SPTR" FLAG\n",
+	mprintf(SPTR"   DEV   BSIZE        TYPE "SPTR"    MAGIC "SPTR" "SPTR" FLAGS\n",
 		"ADDR", "S_OP", "ROOT", "BDEV");
 }
 
@@ -397,7 +397,7 @@ print_char_device(addr)
 	mprintf("%5x ", ATOMIC_READ(cd.count));
 	print_dev_t(cd.dev);
 	mprintf(" %4x ", ATOMIC_READ(cd.openers));
-	mprintf("%5x %3x\n", ATOMIC_READ(cd.sem.count), cd.sem.sleepers);
+	mprintf("%5d %3d\n", ATOMIC_READ(cd.sem.count), cd.sem.sleepers);
 	return (addr_t)cd.hash.next;
 }
 
@@ -424,7 +424,7 @@ print_block_device(addr, eflag)
 	mprintf("%5x ", ATOMIC_READ(bd.bd_count));
 	print_dev_t(bd.bd_dev);
 	mprintf(" %4x " FPTR, bd.bd_openers, bd.bd_op);
-	mprintf(" %5x %3x", ATOMIC_READ(bd.bd_sem.count), bd.bd_sem.sleepers);
+	mprintf(" %5d %3d", ATOMIC_READ(bd.bd_sem.count), bd.bd_sem.sleepers);
 
 	mprintf(" " FPTR " ", bd.bd_inode);
 	iaddr = (addr_t)bd.bd_inodes.next;
