@@ -83,6 +83,6 @@ struct sizetbl sizetbl[] = {
 	{ "vg_t",		sizeof(vg_t) },
 	{ "vm_area_struct",	sizeof(struct vm_area_struct) },
 	{ "wait_queue_head_t",	sizeof(wait_queue_head_t) },
-	{ "zone_t",		sizeof(zone_t) },
+	{ "zone",		sizeof(struct zone) },
 };
 int sizetbl_size = sizeof(sizetbl) / sizeof(sizetbl[0]);
