@@ -20,6 +20,8 @@ extern const commandtable_t
 	command_request_queue,
 	command_rtable,
 	command_slab,
+	command_sock,
+	command_socket,
 	command_timer_vec,
 	command_usb_bus,
 	command_usb_device,
@@ -47,6 +49,8 @@ const commandtable_t *commandtable_vers[] = {
 	&command_request_queue,
 	&command_rtable,
 	&command_slab,
+	&command_sock,
+	&command_socket,
 	&command_timer_vec,
 #ifdef CONFIG_USB
 	&command_usb_bus,
