@@ -25,7 +25,9 @@ print_xfs_mount(addr, flag)
 	char name[32];
 	static const struct bitname mflags[] = {
 		{ XFS_MOUNT_WSYNC,		"wsync" },
+#ifdef XFS_MOUNT_INO64
 		{ XFS_MOUNT_INO64,		"ino64" },
+#endif
 		{ XFS_MOUNT_ROOTQCHECK,		"rootqcheck" },
 		{ XFS_MOUNT_FS_SHUTDOWN,	"fs_shutdown" },
 		{ XFS_MOUNT_NOATIME,		"noatime" },
@@ -76,10 +78,17 @@ print_xfs_mount(addr, flag)
 	mprintf("rbmip    " FPTR "\n", m.m_rbmip);
 	mprintf("rsumip   " FPTR "\n", m.m_rsumip);
 	mprintf("rootip   " FPTR "\n", m.m_rootip);
+#if 1
+	/* new style */
+	mprintf("m_ddev_targp   " FPTR "\n", m.m_ddev_targp);
+	mprintf("m_logdev_targ  " FPTR "\n", m.m_logdev_targp);
+#else
+	/* old fashion */
 	mprintf("m_ddev_targ   " FPTR " " FPTR " %04x\n",
 		m.m_ddev_targ.pb_targ, m.m_ddev_targ.bd_targ, m.m_ddev_targ.dev);
 	mprintf("m_logdev_targ " FPTR " " FPTR " %04x\n",
 		m.m_logdev_targ.pb_targ, m.m_logdev_targ.bd_targ, m.m_logdev_targ.dev);
+#endif
 	mprintf("flags    ");
 	mprintbit(mflags, m.m_flags);
 	mprintf("\n");
