@@ -10,7 +10,9 @@
 #include <linux/fs.h>
 #include <linux/page_buf.h>
 #else
+#ifdef HAVE_AVL
 #include <avl.h>
+#endif
 #include <page_buf.h>
 #endif
 
@@ -54,12 +56,12 @@ print_pagebuf(addr, fflag)
 		mprintf("  relse:  " FPTR "\n", pb.pb_relse);
 		mprintf("  strat:  " FPTR "\n", pb.pb_strat);
 		mprintf("  iodonesema:\n");
-#if 0
+#if 1
 		/* new style */
 		prhead_semaphore();
 		print_semaphore(addr + OFFSET(page_buf_t, pb_iodonesema));
 #else
-		/* old fushion */
+		/* old fashion */
 		prhead_semaphore();
 		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_iodonesema));
 		/*struct page_buf_private_s priv;*/
